( cd opt/kde/lib ; rm -rf libkorganizer.so )
( cd opt/kde/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so )
( cd opt/kde/lib ; rm -rf libkcal.so.2 )
( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so.2 )
( cd opt/kde/lib ; rm -rf libknewstuff.so )
( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so )
( cd opt/kde/lib ; rm -rf libkpilot.so )
( cd opt/kde/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so )
( cd opt/kde/lib ; rm -rf libknewstuff.so.1 )
( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so.1 )
( cd opt/kde/lib ; rm -rf libkdepim.so )
( cd opt/kde/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so )
( cd opt/kde/lib ; rm -rf libkcalsystem.so.0 )
( cd opt/kde/lib ; ln -sf libkcalsystem.so.0.0.1 libkcalsystem.so.0 )
( cd opt/kde/lib ; rm -rf libkgantt.so )
( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so )
( cd opt/kde/lib ; rm -rf libkpimexchange.so )
( cd opt/kde/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so )
( cd opt/kde/lib ; rm -rf libksync.so )
( cd opt/kde/lib ; ln -sf libksync.so.1.0.0 libksync.so )
( cd opt/kde/lib ; rm -rf libkcal.so )
( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so )
( cd opt/kde/lib ; rm -rf libksync.so.1 )
( cd opt/kde/lib ; ln -sf libksync.so.1.0.0 libksync.so.1 )
( cd opt/kde/lib ; rm -rf libkpilot.so.0 )
( cd opt/kde/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so.0 )
( cd opt/kde/lib ; rm -rf libkpimexchange.so.1 )
( cd opt/kde/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so.1 )
( cd opt/kde/lib ; rm -rf libkalarmd.so.0 )
( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so.0 )
( cd opt/kde/lib ; rm -rf libkorganizer.so.1 )
( cd opt/kde/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so.1 )
( cd opt/kde/lib ; rm -rf libkgantt.so.0 )
( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so.0 )
( cd opt/kde/lib ; rm -rf libkcalsystem.so )
( cd opt/kde/lib ; ln -sf libkcalsystem.so.0.0.1 libkcalsystem.so )
( cd opt/kde/lib ; rm -rf libkalarmd.so )
( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so )
( cd opt/kde/lib ; rm -rf libkdepim.so.1 )
( cd opt/kde/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so.1 )
( cd opt/kde/share/doc/HTML/en/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/karm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdepim-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdepim-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kandy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kalarm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/knotes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpilot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/korganizer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
