<!DOCTYPE kpartgui>
<kpartgui name="kaddressbook" version="8">

  <MenuBar>
    <Menu name="file"><text>&amp;File</text>
      <Action name="file_new_contact"/>
      <Action name="file_properties"/>
      <Separator/>
      <Action name="file_sync"/>

      <Menu name="file_import"><text>&amp;Import</text>
        <Action name="file_import_kde2"/>
        <Action name="file_import_vcard"/>
        <Action name="file_import_csv"/>
      </Menu>

      <Menu name="file_export"><text>&amp;Export</text>
        <Action name="file_export_csv"/>
        <Action name="file_export_vcard30"/>
      </Menu>
    </Menu>

    <Menu name="edit"><text>&amp;Edit</text>
      <Action name="edit_delete" append="edit_paste_merge"/>
    </Menu>

    <Menu name="view"><text>&amp;View</text>
      <ActionList name="view_loadedviews"/>
      <Separator/>
      <Action name="view_add"/>
      <Action name="view_modify"/>
      <Action name="view_delete"/>
      <Separator/>
      <Action name="view_refresh"/>
      <Separator/>
      <Action name="select_filter"/>
    </Menu>

    <Menu noMerge="1" name="settings"><text>&amp;Settings</text>
      <Action name="options_show_features"/>
      <Action name="options_show_jump_bar"/>
      <Action name="options_show_details"/>
      <Action name="options_show_statusbar"/>
      <Merge name="show_merge"/>
      <Separator/>
      <Merge/>
      <Action name="options_edit_filters"/>
      <Separator/>
      <Action name="options_configure_keybinding"/>
      <Action name="options_configure_toolbars"/>
      <Action name="options_configure"/>
      <Merge name="configure_merge"/>
    </Menu>

  </MenuBar>

  <ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
    <Action name="file_sync" />
    <Action name="file_print" />
    <Separator/>
    <Action name="file_new_contact"/>
    <Action name="file_properties"/>
    <Separator/>
    <Action name="file_mail"/>
    <Separator/>
    <Action name="ldap_lookup"/>
  </ToolBar>
  
  <ToolBar name="addresseeToolBar" noMerge="1"><text>Contact Toolbar</text>
    <Action name="edit_undo"/>
    <Action name="edit_redo"/> 
    <Separator/>
    <Action name="edit_cut"/>
    <Action name="edit_copy"/>
    <Action name="edit_paste"/>
    <Separator/>
    <Action name="edit_delete"/>
  </ToolBar>
  
  <ToolBar name="viewToolBar" noMerge="1"><text>View Toolbar</text>
    <Action name="view_add"/>
    <Action name="view_modify"/>
    <Action name="view_delete"/>
    <Separator/>
    <Action name="view_refresh"/>
    <Separator/>
    <Action name="options_show_features"/>
  </ToolBar>

  <ToolBar name="filterToolBar" noMerge="1"><text>Filter Toolbar</text>
    <Action name="options_edit_filters"/>
    <Action name="select_filter"/>
  </ToolBar>
  
</kpartgui>
