<!DOCTYPE kpartgui>
<kpartgui name="birthdays" version="1">
  <MenuBar>
    <Menu name="file"><text>&amp;File</text>
      <Menu name="import"><text>Import</text>
        <Action name="import_birthdays" />
      </Menu>
    </Menu>
  </MenuBar>

</kpartgui>
