<!DOCTYPE kpartgui>
<kpartgui name="korganizer" version="10">

  <MenuBar>
    <Menu name="file"><text>&amp;File</text>
      <Action name="print_setup" append="print_merge"/>
      <Action name="import_ical"/>
      <Action name="merge_calendar"/>
      <Action name="file_archive"/>
      <Menu name="export"><text>Export</text>
        <Action name="export_web"/>
        <Separator/>
        <Action name="export_icalendar"/>
        <Action name="export_vcalendar"/>
      </Menu>
      <Separator/>
      <Action name="make_active"/>
    </Menu>
    <Menu name="edit"><text>&amp;Edit</text>
      <Action name="edit_delete" append="edit_paste_merge"/>
    </Menu>
    <Menu name="view"><text>&amp;View</text>
      <Action name="view_whatsnext"/>
      <Separator/>
      <Action name="view_list"/>
      <Action name="view_day"/>
      <Action name="view_workweek"/>
      <Action name="view_week"/>
      <Action name="view_nextx"/>
      <Action name="view_month"/>
      <Action name="view_todo"/>
      <Action name="view_project"/>
      <Action name="view_journal"/>
      <Separator/>
      <Action name="update"/>
    </Menu>
    <Menu name="go_document">
      <Action name="go_today"/>
    </Menu>
    <Menu name="actions"><text>&amp;Actions</text>
      <Action name="new_event"/>
      <Action name="new_todo"/>
      <Separator/>
      <Action name="show_appointment"/>
      <Action name="edit_appointment"/>
      <Action name="mail_appointment"/>
      <Action name="takeover_event"/>
      <Separator/>
      <Action name="takeover_calendar"/>
    </Menu>
    <Menu name="schedule"><text>S&amp;chedule</text>
      <Action name="outgoing"/>
      <Action name="incoming"/>
      <Separator/>
      <Action name="publish"/>
      <Action name="request"/>
      <Action name="refresh"/>
      <Action name="cancel"/>
      <Action name="add"/>
      <Action name="reply"/>
      <Action name="counter"/>
      <Action name="declinecounter"/>
    </Menu>
    <Menu name="settings"><text>&amp;Settings</text>
      <Actionlist name="toolbartoggles" append="show_merge"/>
      <Action name="show_filter" append="show_merge"/>
      <Action name="conf_datetime"/>
      <Action name="edit_filters"/>
      <Action name="edit_categories"/>
    </Menu>
    <Menu name="help"><text>&amp;Help</text>
      <Action name="show_intro"/>
      <Action name="help_tipofday"/>
    </Menu>
  </MenuBar>

  <ToolBar name="mainToolBar"><text>Main</text>
    <Action name="go_today"/>
    <Action name="mail_appointment"/>
    <Action name="new_event"/>
  </ToolBar>

  <ToolBar name="korganizer_toolbar"><text>Views</text>
    <Action name="view_whatsnext"/>
    <Action name="view_list"/>
    <Action name="view_day"/>
    <Action name="view_workweek"/>
    <Action name="view_week"/>
    <Action name="view_nextx"/>
    <Action name="view_month"/>
    <Action name="view_todo"/>
  </ToolBar>

</kpartgui>
