<!DOCTYPE kpartgui>
<kpartgui name="webexport" version="2">
  <MenuBar>
    <Menu name="file"><text>&amp;File</text>
      <Menu name="export"><text>Export</text>
        <Action name="export_web" />
      </Menu>
    </Menu>
  </MenuBar>

</kpartgui>
