<!DOCTYPE kpartgui>
<kpartgui name="exchange" version="1">

  <MenuBar>
    <Menu name="exchange"><text>Exchange</text>
      <Action name="exchange_download" />
      <Action name="exchange_upload" />
      <Action name="exchange_delete" />
      <Action name="exchange_configure" />
    </Menu>
  </MenuBar>

</kpartgui>
